import { JsonApiResponse } from './response';
import { JsonApiClientConfig, JsonApiClientRequestOpts, Url, Uuid } from './types';
/**
 * Represents JsonApiClient that performs requests to backend
 */
export declare class JsonApiClient {
    private _baseUrl;
    protected _authToken: Uuid;
    constructor(config?: JsonApiClientConfig);
    /**
     * Clones current JsonApiClient instance
     */
    private _clone;
    /**
     *  Base URL will be prepended to `url` unless `url` is absolute.
     *  It can be convenient to set `baseURL` for an instance of axios to pass
     *  relative URLs to methods of that instance.
     *
     *  For more details look Axios Request config:
     *  {@link https://github.com/axios/axios#request-config}
     */
    get baseUrl(): Url;
    /**
     * Manages authentication and ownership within its system via bearer
     * tokens and internal identities.
     */
    get authToken(): Uuid;
    /**
     * Sets authentication token to the client instance.
     */
    setAuthToken(authToken: Uuid): JsonApiClient;
    /**
     * Assigns new base URL to the current instance.
     */
    useBaseUrl(baseUrl: Url): JsonApiClient;
    /**
     * Creates new instance JsonApiClient instance with given base URL.
     */
    withBaseUrl(baseUrl: Url): JsonApiClient;
    /**
     * Creates new instance JsonApiClient instance with given auth authToken.
     */
    withAuthToken(authToken: Uuid): JsonApiClient;
    /**
     * Performs a http request
     */
    request<T>(opts: JsonApiClientRequestOpts): Promise<JsonApiResponse<T>>;
    /**
     * Makes a `GET` to a target `endpoint` with the provided `query` params.
     * Parses the response in JsonApi format.
     */
    get<T>(endpoint: string, query?: Record<string, unknown>): Promise<JsonApiResponse<T>>;
    /**
     * Makes a `POST` to a target `endpoint` with the provided `data` as body.
     * Parses the response in JsonApi format.
     */
    post<T>(endpoint: string, data: unknown): Promise<JsonApiResponse<T>>;
    /**
     * Makes a `PATCH` to a target `endpoint` with the provided `data` as body.
     * Signing can be enabled with `needSign` argument. Parses the response in
     * JsonApi format.
     */
    patch<T>(endpoint: string, data?: unknown): Promise<JsonApiResponse<T>>;
    /**
     * Makes a `PUT` to a target `endpoint` with the provided `data` as body.
     * Parses the response in JsonApi format.
     */
    put<T>(endpoint: string, data: unknown): Promise<JsonApiResponse<T>>;
    /**
     * Makes a `DELETE` to a target `endpoint` with the provided `data` as body.
     * Parses the response in JsonApi format.
     */
    delete<T>(endpoint: string, data?: unknown): Promise<JsonApiResponse<T>>;
}
